Buffer

Struct Buffer 

pub struct Buffer { /* private fields */ }
[classBuffer] provides a class for the instantiation of buffers used for the storage of the separate images of the video stream.

The actual data space may either be allocated by [classBuffer] during an object instantiation, of pre-allocated. [classBuffer] also allows the transmission of image metadata, such as offsets and size of the transmitted region of interest, pixel format and time stamp.

Implements

[trait@glib::ObjectExt]

GLib type: GObject with reference counted clone semantics.

Implementations

Source

impl Buffer

pub fn new_allocate(size: usize) -> Buffer

Creates a new buffer for the storage of the video stream images. The data space is allocated by this function, and will be freed when the buffer is destroyed.

size

payload size

Returns

a new Buffer object

pub fn chunk_data(&self, chunk_id: u64) -> Vec<u8>

Chunk data accessor.

chunk_id

chunk id

Returns

a pointer to the chunk data.

pub fn frame_id(&self) -> u64

Gets the buffer frame id. For GigEVision devices, 0 is an invalid value.

Returns

frame id, 0 on error.

pub fn image_height(&self) -> i32

Gets the image width.

This function must only be called if buffer payload is either BufferPayloadType::Image, BufferPayloadType::ExtendedChunkData or BufferPayloadType::Multipart.

Returns

image height, in pixels.

pub fn image_pixel_format(&self) -> PixelFormat

Gets the image pixel format.

This function must only be called if buffer payload is either BufferPayloadType::Image, BufferPayloadType::ExtendedChunkData or BufferPayloadType::Multipart.

Returns

image pixel format.

pub fn image_region(&self) -> (i32, i32, i32, i32)

Gets the image region.

This function must only be called if buffer payload is either BufferPayloadType::Image, BufferPayloadType::ExtendedChunkData or BufferPayloadType::Multipart.

Returns
x

image x offset placeholder

y

image y offset placeholder

width

image width placholder

height

image height placeholder

pub fn image_width(&self) -> i32

Gets the image width.

This function must only be called if buffer payload is either BufferPayloadType::Image, BufferPayloadType::ExtendedChunkData or BufferPayloadType::Multipart.

Returns

image width, in pixels.

pub fn image_x(&self) -> i32

Gets the image x offset.

This function must only be called if buffer payload is either BufferPayloadType::Image, BufferPayloadType::ExtendedChunkData or BufferPayloadType::Multipart.

Returns

image x offset, in pixels.

pub fn image_y(&self) -> i32

Gets the image y offset.

This function must only be called if buffer payload is either BufferPayloadType::Image, BufferPayloadType::ExtendedChunkData or BufferPayloadType::Multipart.

Returns

image y offset, in pixels.

pub fn payload_type(&self) -> BufferPayloadType

Gets the buffer payload type.

Returns

payload type.

pub fn status(&self) -> BufferStatus

Gets the buffer acquisition status.

Returns

buffer acquisition status.

pub fn system_timestamp(&self) -> u64

Gets the system timestamp for when the frame was received. Expressed in nanoseconds.

Returns

buffer system timestamp, in nanoseconds.

pub fn timestamp(&self) -> u64

Gets the buffer camera timestamp, expressed as nanoseconds. Not all devices provide reliable timestamp, which means sometimes its better to rely on the buffer completion host local time, or to use system_timestamp().

Returns

buffer timestamp, in nanoseconds.

pub fn has_chunks(&self) -> bool

Returns

true if self has a payload type that contains chunk data.

pub fn set_system_timestamp(&self, timestamp_ns: u64)

Sets the system timestamp for when the frame was received. Expressed in nanoseconds.

timestamp_ns

a timestamp, expressed as nanoseconds

pub fn set_timestamp(&self, timestamp_ns: u64)

Sets the buffer timestamp, which allows to override the timpestamp set by the camera, which in some case is incorrect.

timestamp_ns

a timestamp, expressed as nanoseconds

Source

impl Buffer

pub fn new_preallocated_owned<F: FnOnce()>( data: *mut u8, len: usize, destroy_callback: F, ) -> Self

Create an Aravis buffer that owns its own data from a pre-allocated raw buffer.

The destroy_callback argument is called to destroy the buffer, and should free the resources associated with the buffer.

Safety

The pointer and length parameter must indicate a valid memory region where Aravis can safely write data to until the destroy_callback is called.

pub unsafe fn new_preallocated(data: *mut u8, len: usize) -> Self

👎Deprecated: Use new_preallocated_borrowed instead

Create an Aravis buffer from a pre-allocated raw buffer.

The created buffer has no registered user data or destroy callback, so management of the underlying buffer has to be done externally. The buffer can be identified later when it is returned by a stream only byt the data pointer.

Safety

The resulting buffer borrows the data, but it carries no lifetime. The user has to ensure the buffer stays valid.

pub unsafe fn new_preallocated_borrowed(data: *mut u8, len: usize) -> Self

Create an Aravis buffer from a pre-allocated raw buffer.

The created buffer has no registered user data or destroy callback, so management of the underlying buffer has to be done externally. The buffer can be identified later when it is returned by a stream only by the data pointer.

Safety

The pointer and length parameter must indicate a valid memory region where Aravis can safely write data to until the buffer is dropped. The created buffer borrows the memory buffer, but it carries no lifetime. See Self::new_preallocated_owned for a safer (but still unsafe) alternative.

pub fn new_leaked_box(len: usize) -> Self

Create a new buffer backed by a leaked Box<[u8]>.

The buffer can later be turned into an image using [Self::into_image]. If the buffer is dropped without taking ownership of the data again, the memory is leaked.

pub fn new_leaked_image( format: PixelFormat, width: usize, height: usize, ) -> Self

Create a new buffer for an image of the specified format and dimensions, backed by a leaked Box<[u8]>.

The buffer can later be turned into an image using [Self::into_image]. If the buffer is dropped without taking ownership of the data again, the memory is leaked.

pub fn data(&self) -> (*mut u8, usize)

Get a pointer to the raw data and the length of the buffer.

pub unsafe fn into_boxed_slice(self) -> Box<[u8]>

Convert the buffer into a boxed slice.

Safety

This function assumes the buffer is backed by a leaked box, such as created by Buffer::new_leaked_box.

This function assumes ownership of the leaked box.

pub unsafe fn into_image(self) -> Result<DynamicImage, ImageError>

Available on crate feature image only.

Convert the buffer into an image.

Safety

This function assumes the buffer is backed by a leaked box, such as created by Buffer::new_leaked_box.

This function takes ownership of the leaked box, so the memory will be freed when the resulting image is dropped.